#!/usr/bin/env bash
# Required variables
export SEL_TOKEN=MNhA6zVcf7x892LqsQSc9vDN_9999
export SEL_URL=https://api.selectel.ru/vpc/resell
export OS_AUTH_URL=https://cloud.api.selcloud.ru/identity/v3

# Optional variables
export SEL_API_VERSION=2
